summaryrefslogtreecommitdiff
path: root/drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h')
-rw-r--r--drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h b/drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h
index ab29e9d9c0a6..5fc6d9e1c312 100644
--- a/drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h
+++ b/drivers/gpu/arm/midgard/platform/juno_soc/mali_kbase_config_platform.h
@@ -1,6 +1,6 @@
/*
*
- * (C) COPYRIGHT 2014-2016 ARM Limited. All rights reserved.
+ * (C) COPYRIGHT 2014-2015 ARM Limited. All rights reserved.
*
* This program is free software and is provided to you under the terms of the
* GNU General Public License version 2 as published by the Free Software
@@ -71,14 +71,14 @@
#define PLATFORM_FUNCS (NULL)
/**
* Protected mode switch
*
* Attached value: pointer to @ref kbase_protected_ops
*/
-#define PROTECTED_CALLBACKS (&juno_protected_ops)
+#define SECURE_CALLBACKS (&juno_secure_ops)
extern struct kbase_pm_callback_conf pm_callbacks;
#ifdef CONFIG_DEVFREQ_THERMAL
extern struct devfreq_cooling_ops juno_model_ops;
#endif
-extern struct kbase_protected_ops juno_protected_ops;
+extern struct kbase_secure_ops juno_secure_ops;
@@ -71,14 +71,14 @@
#define PLATFORM_FUNCS (NULL)
/**
- * Protected mode switch
+ * Secure mode switch
*
@@ -71,14 +71,14 @@
*
- * Attached value: pointer to @ref kbase_protected_ops
+ * Attached value: pointer to @ref kbase_secure_ops
*/